==> webpdf-wsclient-1.0.1-sources.jar: net/webpdf/wsclient/schema/operation/OperationData.java <==

package net.webpdf.wsclient.schema.operation;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for operation element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="operation"&gt;
 *   &lt;complexType&gt;
 *     &lt;complexContent&gt;
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *         &lt;sequence&gt;
 *           &lt;element name="billing" type="{http://schema.webpdf.de/1.0/operation}BillingType" minOccurs="0"/&gt;
 *           &lt;element name="password" type="{http://schema.webpdf.de/1.0/operation}PdfPasswordType" minOccurs="0"/&gt;
 *           &lt;choice&gt;
 *             &lt;element name="barcode" type="{http://schema.webpdf.de/1.0/operation}BarcodeType"/&gt;
 *             &lt;element name="converter" type="{http://schema.webpdf.de/1.0/operation}ConverterType"/&gt;
 *             &lt;element name="ocr" type="{http://schema.webpdf.de/1.0/operation}OcrType"/&gt;
 *             &lt;element name="pdfa" type="{http://schema.webpdf.de/1.0/operation}PdfaType"/&gt;
 *             &lt;element name="signature" type="{http://schema.webpdf.de/1.0/operation}SignatureType"/&gt;
 *             &lt;choice maxOccurs="unbounded"&gt;
 *               &lt;element name="annotation" type="{http://schema.webpdf.de/1.0/operation}AnnotationType"/&gt;
 *               &lt;element name="attachment" type="{http://schema.webpdf.de/1.0/operation}AttachmentType"/&gt;
 *               &lt;element name="delete" type="{http://schema.webpdf.de/1.0/operation}DeleteType"/&gt;
 *               &lt;element name="description" type="{http://schema.webpdf.de/1.0/operation}DescriptionType"/&gt;
 *               &lt;element name="extraction" type="{http://schema.webpdf.de/1.0/operation}ExtractionType"/&gt;
 *               &lt;element name="forms" type="{http://schema.webpdf.de/1.0/operation}FormsType"/&gt;
 *               &lt;element name="image" type="{http://schema.webpdf.de/1.0/operation}ImageType"/&gt;
 *               &lt;element name="merge" type="{http://schema.webpdf.de/1.0/operation}MergeType"/&gt;
 *               &lt;element name="options" type="{http://schema.webpdf.de/1.0/operation}OptionsType"/&gt;
 *               &lt;element name="print" type="{http://schema.webpdf.de/1.0/operation}PrintType"/&gt;
 *               &lt;element name="rotate" type="{http://schema.webpdf.de/1.0/operation}RotateType"/&gt;
 *               &lt;element name="security" type="{http://schema.webpdf.de/1.0/operation}SecurityType"/&gt;
 *               &lt;element name="split" type="{http://schema.webpdf.de/1.0/operation}SplitType"/&gt;
 *               &lt;element name="watermark" type="{http://schema.webpdf.de/1.0/operation}WatermarkType"/&gt;
 *               &lt;element name="xmp" type="{http://schema.webpdf.de/1.0/operation}XmpType"/&gt;
 *             &lt;/choice&gt;
 *             &lt;element name="urlconverter" type="{http://schema.webpdf.de/1.0/operation}UrlConverterType"/&gt;
 *           &lt;/choice&gt;
 *         &lt;/sequence&gt;
 *       &lt;/restriction&gt;
 *     &lt;/complexContent&gt;
 *   &lt;/complexType&gt;
 * &lt;/element&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "billing",
    "password",
    "barcode",
    "converter",
    "ocr",
    "pdfa",
    "signature",
    "toolbox",
    "urlconverter"
})
@XmlRootElement(name = "operation")
public class OperationData {

    protected BillingType billing;
    protected PdfPasswordType password;
    protected BarcodeType barcode;
    protected ConverterType converter;
    protected OcrType ocr;
    protected PdfaType pdfa;
    protected SignatureType signature;
    @XmlElements({
        @XmlElement(name = "annotation", type = AnnotationType.class),
        @XmlElement(name = "attachment", type = AttachmentType.class),
        @XmlElement(name = "delete", type = DeleteType.class),
        @XmlElement(name = "description", type = DescriptionType.class),
        @XmlElement(name = "extraction", type = ExtractionType.class),
        @XmlElement(name = "forms", type = FormsType.class),
        @XmlElement(name = "image", type = ImageType.class),
        @XmlElement(name = "merge", type = MergeType.class),
        @XmlElement(name = "options", type = OptionsType.class),
        @XmlElement(name = "print", type = PrintType.class),
        @XmlElement(name = "rotate", type = RotateType.class),
        @XmlElement(name = "security", type = SecurityType.class),
        @XmlElement(name = "split", type = SplitType.class),
        @XmlElement(name = "watermark", type = WatermarkType.class),
        @XmlElement(name = "xmp", type = XmpType.class)
    })
    protected List<BaseToolboxType> toolbox;
    protected UrlConverterType urlconverter;

    /**
     * Gets the value of the billing property.
     * 
     * @return
     *     possible object is
     *     {@link BillingType }
     *     
     */
    public BillingType getBilling() {
        return billing;
    }

    /**
     * Sets the value of the billing property.
     * 
     * @param value
     *     allowed object is
     *     {@link BillingType }
     *     
     */
    public void setBilling(BillingType value) {
        this.billing = value;
    }

    public boolean isSetBilling() {
        return (this.billing!= null);
    }

    /**
     * Gets the value of the password property.
     * 
     * @return
     *     possible object is
     *     {@link PdfPasswordType }
     *     
     */
    public PdfPasswordType getPassword() {
        return password;
    }

    /**
     * Sets the value of the password property.
     * 
     * @param value
     *     allowed object is
     *     {@link PdfPasswordType }
     *     
     */
    public void setPassword(PdfPasswordType value) {
        this.password = value;
    }

    public boolean isSetPassword() {
        return (this.password!= null);
    }

    /**
     * Gets the value of the barcode property.
     * 
     * @return
     *     possible object is
     *     {@link BarcodeType }
     *     
     */
    public BarcodeType getBarcode() {
        return barcode;
    }

    /**
     * Sets the value of the barcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link BarcodeType }
     *     
     */
    public void setBarcode(BarcodeType value) {
        this.barcode = value;
    }

    public boolean isSetBarcode() {
        return (this.barcode!= null);
    }

    /**
     * Gets the value of the converter property.
     * 
     * @return
     *     possible object is
     *     {@link ConverterType }
     *     
     */
    public ConverterType getConverter() {
        return converter;
    }

    /**
     * Sets the value of the converter property.
     * 
     * @param value
     *     allowed object is
     *     {@link ConverterType }
     *     
     */
    public void setConverter(ConverterType value) {
        this.converter = value;
    }

    public boolean isSetConverter() {
        return (this.converter!= null);
    }

    /**
     * Gets the value of the ocr property.
     * 
     * @return
     *     possible object is
     *     {@link OcrType }
     *     
     */
    public OcrType getOcr() {
        return ocr;
    }

    /**
     * Sets the value of the ocr property.
     * 
     * @param value
     *     allowed object is
     *     {@link OcrType }
     *     
     */
    public void setOcr(OcrType value) {
        this.ocr = value;
    }

    public boolean isSetOcr() {
        return (this.ocr!= null);
    }

    /**
     * Gets the value of the pdfa property.
     * 
     * @return
     *     possible object is
     *     {@link PdfaType }
     *     
     */
    public PdfaType getPdfa() {
        return pdfa;
    }

    /**
     * Sets the value of the pdfa property.
     * 
     * @param value
     *     allowed object is
     *     {@link PdfaType }
     *     
     */
    public void setPdfa(PdfaType value) {
        this.pdfa = value;
    }

    public boolean isSetPdfa() {
        return (this.pdfa!= null);
    }

    /**
     * Gets the value of the signature property.
     * 
     * @return
     *     possible object is
     *     {@link SignatureType }
     *     
     */
    public SignatureType getSignature() {
        return signature;
    }

    /**
     * Sets the value of the signature property.
     * 
     * @param value
     *     allowed object is
     *     {@link SignatureType }
     *     
     */
    public void setSignature(SignatureType value) {
        this.signature = value;
    }

    public boolean isSetSignature() {
        return (this.signature!= null);
    }

    /**
     * Gets the value of the toolbox property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the toolbox property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getToolbox().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link AnnotationType }
     * {@link AttachmentType }
     * {@link DeleteType }
     * {@link DescriptionType }
     * {@link ExtractionType }
     * {@link FormsType }
     * {@link ImageType }
     * {@link MergeType }
     * {@link OptionsType }
     * {@link PrintType }
     * {@link RotateType }
     * {@link SecurityType }
     * {@link SplitType }
     * {@link WatermarkType }
     * {@link XmpType }
     * 
     * 
     */
    public List<BaseToolboxType> getToolbox() {
        if (toolbox == null) {
            toolbox = new ArrayList<BaseToolboxType>();
        }
        return this.toolbox;
    }

    public boolean isSetToolbox() {
        return ((this.toolbox!= null)&&(!this.toolbox.isEmpty()));
    }

    public void unsetToolbox() {
        this.toolbox = null;
    }

    /**
     * Gets the value of the urlconverter property.
     * 
     * @return
     *     possible object is
     *     {@link UrlConverterType }
     *     
     */
    public UrlConverterType getUrlconverter() {
        return urlconverter;
    }

    /**
     * Sets the value of the urlconverter property.
     * 
     * @param value
     *     allowed object is
     *     {@link UrlConverterType }
     *     
     */
    public void setUrlconverter(UrlConverterType value) {
        this.urlconverter = value;
    }

    public boolean isSetUrlconverter() {
        return (this.urlconverter!= null);
    }

}

==> webpdf-wsclient-2.0.1-sources.jar: net/webpdf/wsclient/schema/operation/OperationData.java <==

package net.webpdf.wsclient.schema.operation;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for operation element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="operation"&gt;
 *   &lt;complexType&gt;
 *     &lt;complexContent&gt;
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *         &lt;sequence&gt;
 *           &lt;element name="billing" type="{http://schema.webpdf.de/1.0/operation}BillingType" minOccurs="0"/&gt;
 *           &lt;element name="password" type="{http://schema.webpdf.de/1.0/operation}PdfPasswordType" minOccurs="0"/&gt;
 *           &lt;choice&gt;
 *             &lt;element name="barcode" type="{http://schema.webpdf.de/1.0/operation}BarcodeType"/&gt;
 *             &lt;element name="converter" type="{http://schema.webpdf.de/1.0/operation}ConverterType"/&gt;
 *             &lt;element name="ocr" type="{http://schema.webpdf.de/1.0/operation}OcrType"/&gt;
 *             &lt;element name="pdfa" type="{http://schema.webpdf.de/1.0/operation}PdfaType"/&gt;
 *             &lt;element name="signature" type="{http://schema.webpdf.de/1.0/operation}SignatureType"/&gt;
 *             &lt;choice maxOccurs="unbounded"&gt;
 *               &lt;element name="annotation" type="{http://schema.webpdf.de/1.0/operation}AnnotationType"/&gt;
 *               &lt;element name="attachment" type="{http://schema.webpdf.de/1.0/operation}AttachmentType"/&gt;
 *               &lt;element name="delete" type="{http://schema.webpdf.de/1.0/operation}DeleteType"/&gt;
 *               &lt;element name="description" type="{http://schema.webpdf.de/1.0/operation}DescriptionType"/&gt;
 *               &lt;element name="extraction" type="{http://schema.webpdf.de/1.0/operation}ExtractionType"/&gt;
 *               &lt;element name="forms" type="{http://schema.webpdf.de/1.0/operation}FormsType"/&gt;
 *               &lt;element name="image" type="{http://schema.webpdf.de/1.0/operation}ImageType"/&gt;
 *               &lt;element name="merge" type="{http://schema.webpdf.de/1.0/operation}MergeType"/&gt;
 *               &lt;element name="options" type="{http://schema.webpdf.de/1.0/operation}OptionsType"/&gt;
 *               &lt;element name="print" type="{http://schema.webpdf.de/1.0/operation}PrintType"/&gt;
 *               &lt;element name="rotate" type="{http://schema.webpdf.de/1.0/operation}RotateType"/&gt;
 *               &lt;element name="security" type="{http://schema.webpdf.de/1.0/operation}SecurityType"/&gt;
 *               &lt;element name="split" type="{http://schema.webpdf.de/1.0/operation}SplitType"/&gt;
 *               &lt;element name="watermark" type="{http://schema.webpdf.de/1.0/operation}WatermarkType"/&gt;
 *               &lt;element name="xmp" type="{http://schema.webpdf.de/1.0/operation}XmpType"/&gt;
 *               &lt;element name="move" type="{http://schema.webpdf.de/1.0/operation}MoveType"/&gt;
 *               &lt;element name="outline" type="{http://schema.webpdf.de/1.0/operation}OutlineType"/&gt;
 *               &lt;element name="redact" type="{http://schema.webpdf.de/1.0/operation}RedactType"/&gt;
 *               &lt;element name="portfolio" type="{http://schema.webpdf.de/1.0/operation}PortfolioType"/&gt;
 *             &lt;/choice&gt;
 *             &lt;element name="urlconverter" type="{http://schema.webpdf.de/1.0/operation}UrlConverterType"/&gt;
 *           &lt;/choice&gt;
 *         &lt;/sequence&gt;
 *       &lt;/restriction&gt;
 *     &lt;/complexContent&gt;
 *   &lt;/complexType&gt;
 * &lt;/element&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "billing",
    "password",
    "barcode",
    "converter",
    "ocr",
    "pdfa",
    "signature",
    "toolbox",
    "urlconverter"
})
@XmlRootElement(name = "operation")
public class OperationData {

    protected BillingType billing;
    protected PdfPasswordType password;
    protected BarcodeType barcode;
    protected ConverterType converter;
    protected OcrType ocr;
    protected PdfaType pdfa;
    protected SignatureType signature;
    @XmlElements({
        @XmlElement(name = "annotation", type = AnnotationType.class),
        @XmlElement(name = "attachment", type = AttachmentType.class),
        @XmlElement(name = "delete", type = DeleteType.class),
        @XmlElement(name = "description", type = DescriptionType.class),
        @XmlElement(name = "extraction", type = ExtractionType.class),
        @XmlElement(name = "forms", type = FormsType.class),
        @XmlElement(name = "image", type = ImageType.class),
        @XmlElement(name = "merge", type = MergeType.class),
        @XmlElement(name = "options", type = OptionsType.class),
        @XmlElement(name = "print", type = PrintType.class),
        @XmlElement(name = "rotate", type = RotateType.class),
        @XmlElement(name = "security", type = SecurityType.class),
        @XmlElement(name = "split", type = SplitType.class),
        @XmlElement(name = "watermark", type = WatermarkType.class),
        @XmlElement(name = "xmp", type = XmpType.class),
        @XmlElement(name = "move", type = MoveType.class),
        @XmlElement(name = "outline", type = OutlineType.class),
        @XmlElement(name = "redact", type = RedactType.class),
        @XmlElement(name = "portfolio", type = PortfolioType.class)
    })
    protected List<BaseToolboxType> toolbox;
    protected UrlConverterType urlconverter;

    /**
     * Gets the value of the billing property.
     * 
     * @return
     *     possible object is
     *     {@link BillingType }
     *     
     */
    public BillingType getBilling() {
        return billing;
    }

    /**
     * Sets the value of the billing property.
     * 
     * @param value
     *     allowed object is
     *     {@link BillingType }
     *     
     */
    public void setBilling(BillingType value) {
        this.billing = value;
    }

    public boolean isSetBilling() {
        return (this.billing!= null);
    }

    /**
     * Gets the value of the password property.
     * 
     * @return
     *     possible object is
     *     {@link PdfPasswordType }
     *     
     */
    public PdfPasswordType getPassword() {
        return password;
    }

    /**
     * Sets the value of the password property.
     * 
     * @param value
     *     allowed object is
     *     {@link PdfPasswordType }
     *     
     */
    public void setPassword(PdfPasswordType value) {
        this.password = value;
    }

    public boolean isSetPassword() {
        return (this.password!= null);
    }

    /**
     * Gets the value of the barcode property.
     * 
     * @return
     *     possible object is
     *     {@link BarcodeType }
     *     
     */
    public BarcodeType getBarcode() {
        return barcode;
    }

    /**
     * Sets the value of the barcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link BarcodeType }
     *     
     */
    public void setBarcode(BarcodeType value) {
        this.barcode = value;
    }

    public boolean isSetBarcode() {
        return (this.barcode!= null);
    }

    /**
     * Gets the value of the converter property.
     * 
     * @return
     *     possible object is
     *     {@link ConverterType }
     *     
     */
    public ConverterType getConverter() {
        return converter;
    }

    /**
     * Sets the value of the converter property.
     * 
     * @param value
     *     allowed object is
     *     {@link ConverterType }
     *     
     */
    public void setConverter(ConverterType value) {
        this.converter = value;
    }

    public boolean isSetConverter() {
        return (this.converter!= null);
    }

    /**
     * Gets the value of the ocr property.
     * 
     * @return
     *     possible object is
     *     {@link OcrType }
     *     
     */
    public OcrType getOcr() {
        return ocr;
    }

    /**
     * Sets the value of the ocr property.
     * 
     * @param value
     *     allowed object is
     *     {@link OcrType }
     *     
     */
    public void setOcr(OcrType value) {
        this.ocr = value;
    }

    public boolean isSetOcr() {
        return (this.ocr!= null);
    }

    /**
     * Gets the value of the pdfa property.
     * 
     * @return
     *     possible object is
     *     {@link PdfaType }
     *     
     */
    public PdfaType getPdfa() {
        return pdfa;
    }

    /**
     * Sets the value of the pdfa property.
     * 
     * @param value
     *     allowed object is
     *     {@link PdfaType }
     *     
     */
    public void setPdfa(PdfaType value) {
        this.pdfa = value;
    }

    public boolean isSetPdfa() {
        return (this.pdfa!= null);
    }

    /**
     * Gets the value of the signature property.
     * 
     * @return
     *     possible object is
     *     {@link SignatureType }
     *     
     */
    public SignatureType getSignature() {
        return signature;
    }

    /**
     * Sets the value of the signature property.
     * 
     * @param value
     *     allowed object is
     *     {@link SignatureType }
     *     
     */
    public void setSignature(SignatureType value) {
        this.signature = value;
    }

    public boolean isSetSignature() {
        return (this.signature!= null);
    }

    /**
     * Gets the value of the toolbox property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the toolbox property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getToolbox().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link AnnotationType }
     * {@link AttachmentType }
     * {@link DeleteType }
     * {@link DescriptionType }
     * {@link ExtractionType }
     * {@link FormsType }
     * {@link ImageType }
     * {@link MergeType }
     * {@link OptionsType }
     * {@link PrintType }
     * {@link RotateType }
     * {@link SecurityType }
     * {@link SplitType }
     * {@link WatermarkType }
     * {@link XmpType }
     * {@link MoveType }
     * {@link OutlineType }
     * {@link RedactType }
     * {@link PortfolioType }
     * 
     * 
     */
    public List<BaseToolboxType> getToolbox() {
        if (toolbox == null) {
            toolbox = new ArrayList<BaseToolboxType>();
        }
        return this.toolbox;
    }

    public boolean isSetToolbox() {
        return ((this.toolbox!= null)&&(!this.toolbox.isEmpty()));
    }

    public void unsetToolbox() {
        this.toolbox = null;
    }

    /**
     * Gets the value of the urlconverter property.
     * 
     * @return
     *     possible object is
     *     {@link UrlConverterType }
     *     
     */
    public UrlConverterType getUrlconverter() {
        return urlconverter;
    }

    /**
     * Sets the value of the urlconverter property.
     * 
     * @param value
     *     allowed object is
     *     {@link UrlConverterType }
     *     
     */
    public void setUrlconverter(UrlConverterType value) {
        this.urlconverter = value;
    }

    public boolean isSetUrlconverter() {
        return (this.urlconverter!= null);
    }

}
